summaryrefslogtreecommitdiffstats
path: root/src/opk.h
diff options
context:
space:
mode:
authorPatrick McDermott <patrick.mcdermott@libiquity.com>2023-04-19 11:17:35 (EDT)
committer Patrick McDermott <patrick.mcdermott@libiquity.com>2023-04-19 11:25:26 (EDT)
commit2901b2c9c6389235932be187607c398ef20cb79a (patch)
tree7776b9f76fd1bddb17501e06b22bbdd8ee2ed7dc /src/opk.h
parentc91c1fa46dfc773090489f1802e4470a007b2cf7 (diff)
opk: Automatically initialize inner gzip and ustar
Simplifies interface to main().
Diffstat (limited to 'src/opk.h')
-rw-r--r--src/opk.h35
1 files changed, 4 insertions, 31 deletions
diff --git a/src/opk.h b/src/opk.h
index 8a8cc54..0677071 100644
--- a/src/opk.h
+++ b/src/opk.h
@@ -29,28 +29,11 @@ struct opkg_opk_opk;
* Parameters:
* - file_name: Package's file name.
* Returns:
* - Allocated package structure on success. Free with
* opkg_opk_opk_free_outer().
* - NULL on memory exhaustion.
*/
struct opkg_opk_opk *
-opkg_opk_opk_init_outer(const char *file_name);
-
-/*
- * Initializes an inner archive of a package. Free with
- * opkg_opk_opk_free_outer(). May be called again after freeing.
- * Parameters:
- * - opk: Package structure.
- * - member: Name of member file to find and prepare to read. Should be either
- * "control.tar.gz" or "data.tar.gz", in that order if both are to be read.
- * Returns:
- * - OPKG_OPK_OK if the inner archive is found and initialized.
- * - OPKG_OPK_ERROR if no matching member is found or on decompression error,
- * premature end of gzip stream, an invalid header, unsupported file type, or
- * memory exhaustion.
- */
-int
-opkg_opk_opk_init_inner(struct opkg_opk_opk *opk, const char *member);
+opkg_opk_opk_init(const char *file_name);
/*
* Reads and prints all specified control files.
@@ -81,21 +64,11 @@ int
opkg_opk_opk_list_members(struct opkg_opk_opk *opk);
/*
- * Frees a package structure's inner archive. Call before
- * opkg_opk_opk_free_outer() if a opkg_opk_opk_init_inner() call succeeds.
- * Parameters:
- * - opk: Package structure.
- */
-void
-opkg_opk_opk_free_inner(struct opkg_opk_opk *opk);
-
-/*
- * Frees a package structure. Call opkg_opk_opk_free_inner() first after a
- * successful opkg_opk_opk_init_inner() call.
+ * Frees a package structure.
* Parameters:
* - opk: Package structure.
*/
void
-opkg_opk_opk_free_outer(struct opkg_opk_opk *opk);
+opkg_opk_opk_free(struct opkg_opk_opk *opk);
#endif /* OPKG_OPK_OPK_H_ */
@@ -29,28 +29,11 @@ struct opkg_opk_opk;
* - file_name: Package's file name.
* Returns:
- * - Allocated package structure on success. Free with
- * opkg_opk_opk_free_outer().
+ * - Allocated package structure on success. Free with opkg_opk_opk_free().
* - NULL on memory exhaustion.
*/